/*
 * Copyright (c) 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <glib.h>
#include <string.h>

/*** API implementation ******************************************************/

/**
 * st_pls_parse:
 * @playlist: the playlist data to parse.
 *
 * Parses a SHOUTcast PLS playlist.
 *
 * Return value: the list of URIs contained in @playlist. The list
 * should be freed using g_slist_foreach(list, (GFunc) g_free, NULL);
 * g_slist_free(list); when no longer needed.
 **/
GSList *
st_pls_parse (const char *playlist)
{
  GSList *list = NULL;
  char **lines;
  int i;

  g_return_val_if_fail(playlist != NULL, NULL);

  lines = g_strsplit(playlist, "\n", 0);

  for (i = 0; lines[i]; i++)
    if (g_str_has_prefix(lines[i], "File"))
      {
	char *equal;
	
	equal = strchr(lines[i], '=');
	if (equal)
	  {
	    char *url;
	    
	    url = g_strdup(equal + 1);
	    list = g_slist_append(list, url);
	  }
      }

  g_strfreev(lines);

  return list;
}
